﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.DesktopEdition;

namespace CartoTestWMS
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            
        }

        private void btWithoutParameters_Click(object sender, EventArgs e)
        {
            AddLog("");
            AddLog("Loading without parameters START");
            map.Overlays.Clear();
            map.MapUnit = GeographyUnit.Meter;

            try
            {
                WmsRasterLayer worldLayer = new WmsRasterLayer();
                worldLayer.Uri = new Uri("http://wms.geo.admin.ch/");

                worldLayer.UpperThreshold = double.MaxValue;
                worldLayer.LowerThreshold = 0;

                worldLayer.TimeoutInSecond = 60;

                worldLayer.Exceptions = "Application/VND.OGC.SE_XML";

                worldLayer.Parameters["REQUEST"] = "GetMap";
                worldLayer.Parameters["OUTPUTFORMAT"] = "image/png";
                worldLayer.Parameters["SERVICE"] = "WMS";
                worldLayer.Parameters["STYLES"] = "default";
                worldLayer.Parameters["SRS"] = "EPSG:21781";

                worldLayer.ActiveLayerNames.Add("ch.blw.ursprungsbezeichnungen-spirituosen-eau_vie_poire");

                GoogleMapZoomLevelSet zoomLevelSet = new GoogleMapZoomLevelSet();
                zoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                map.ZoomLevelSet = zoomLevelSet;

                if (worldLayer.HasBoundingBox)
                {
                    worldLayer.Open();
                    map.CurrentExtent = worldLayer.GetBoundingBox();
                    AddLog("Bbox : " + map.CurrentExtent.GetWellKnownText());
                    worldLayer.Close();
                }

                LayerOverlay staticOverlay = new LayerOverlay();

                staticOverlay.Layers.Add("WMS", worldLayer);
                map.Overlays.Add("WMS", staticOverlay);

                map.Refresh();
                AddLog("Loading without parameters END");
            }
            catch (Exception ex)
            {
                AddLog("ERROR : " + ex.Message);
            }
        }

        private void btWithParameters_Click(object sender, EventArgs e)
        {
            AddLog("");
            AddLog("Loading with parameters START");
            map.Overlays.Clear();
            map.MapUnit = GeographyUnit.Meter;

            try
            {
                WmsRasterLayer worldLayer = new WmsRasterLayer();
                worldLayer.Uri = new Uri("http://wms.geo.admin.ch/");

                worldLayer.UpperThreshold = double.MaxValue;
                worldLayer.LowerThreshold = 0;

                worldLayer.TimeoutInSecond = 60;

                worldLayer.Exceptions = "Application/VND.OGC.SE_XML";

                worldLayer.Parameters["REQUEST"] = "GetMap";
                worldLayer.Parameters["OUTPUTFORMAT"] = "image/png";
                worldLayer.Parameters["SERVICE"] = "WMS";
                worldLayer.Parameters["STYLES"] = "default";
                worldLayer.Parameters["SRS"] = "EPSG:21781";

                worldLayer.ActiveLayerNames.Add("ch.blw.ursprungsbezeichnungen-spirituosen-eau_vie_poire");

                worldLayer.Parameters["BBOX"] = "550000,60000,660000,140000";
                worldLayer.Parameters["WIDTH"] = map.Width.ToString();
                worldLayer.Parameters["HEIGHT"] = map.Height.ToString();
                
                GoogleMapZoomLevelSet zoomLevelSet = new GoogleMapZoomLevelSet();
                zoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                map.ZoomLevelSet = zoomLevelSet;

                if (worldLayer.HasBoundingBox)
                {
                    worldLayer.Open();
                    map.CurrentExtent = worldLayer.GetBoundingBox();
                    AddLog("Bbox : " + map.CurrentExtent.GetWellKnownText());
                    worldLayer.Close();
                }

                LayerOverlay staticOverlay = new LayerOverlay();

                staticOverlay.Layers.Add("WMS", worldLayer);
                map.Overlays.Add("WMS", staticOverlay);

                map.Refresh();
                AddLog("Loading with parameters END");

            }
            catch (Exception ex)
            {
                AddLog("ERROR : " + ex.Message);
            }
        }

        private void AddLog(string text)
        {
            this.infoBox.AppendText(text + Environment.NewLine);
        }

    }
}
